@@ -8,6 +8,7 @@
 #
 ######################################################################
 """ generates a dot file with SqliteAccountInfo database structure """
+from __future__ import annotations
 
 import tempfile
 import operator
@@ -15,7 +16,7 @@ import operator
 from sadisplay import describe, render
 from sqlalchemy import create_engine, MetaData
 
-from b2sdk.account_info.sqlite_account_info import SqliteAccountInfo
+from b2sdk._internal.account_info.sqlite_account_info import SqliteAccountInfo
 
 
 def main():
