@@ -36,7 +36,7 @@ from apiver_deps import (
 )
 from apiver_deps_exception import AccessDenied, FileNotPresent, InvalidArgument, RestrictedBucket
 
-from ..test_base import create_key
+from ..test_base import create_key, create_key_multibucket
 
 if apiver_deps.V <= 1:
     from apiver_deps import FileVersionInfo as VFileVersion
@@ -385,6 +385,23 @@ class TestApi:
         )
         assert [b.name for b in self.api.list_buckets(bucket_name=bucket1.name)] == ['bucket1']
 
+    @pytest.mark.apiver(from_ver=3)
+    def test_list_buckets_with_restriction_multi_bucket(self):
+        self._authorize_account()
+        bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
+        self.api.create_bucket('bucket3', 'allPrivate')
+        key = create_key_multibucket(
+            self.api, ['listBuckets'], 'key1', bucket_ids=[bucket1.id_, bucket2.id_]
+        )
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
+        assert [b.name for b in self.api.list_buckets(bucket_name=bucket1.name)] == ['bucket1']
+        assert [b.name for b in self.api.list_buckets(bucket_name=bucket2.name)] == ['bucket2']
+
     def test_get_bucket_by_name_with_bucket_restriction(self):
         self._authorize_account()
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
@@ -396,7 +413,8 @@ class TestApi:
         )
         assert self.api.get_bucket_by_name('bucket1').id_ == bucket1.id_
 
-    def test_list_buckets_with_restriction_and_wrong_name(self):
+    @pytest.mark.apiver(to_ver=2)
+    def test_list_buckets_with_restriction_and_wrong_name_v2(self):
         self._authorize_account()
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
@@ -410,7 +428,25 @@ class TestApi:
             self.api.list_buckets(bucket_name=bucket2.name)
         assert str(excinfo.value) == 'Application key is restricted to bucket: bucket1'
 
-    def test_list_buckets_with_restriction_and_no_name(self):
+    @pytest.mark.apiver(from_ver=3)
+    def test_list_buckets_with_restriction_and_wrong_name_v3(self):
+        self._authorize_account()
+        bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
+        bucket3 = self.api.create_bucket('bucket3', 'allPrivate')
+        key = create_key_multibucket(
+            self.api, ['listBuckets'], 'key1', bucket_ids=[bucket1.id_, bucket2.id_]
+        )
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
+        with pytest.raises(RestrictedBucket, match="\['bucket1', 'bucket2'\]"):
+            self.api.list_buckets(bucket_name=bucket3.name)
+
+    @pytest.mark.apiver(to_ver=2)
+    def test_list_buckets_with_restriction_and_no_name_v2(self):
         self._authorize_account()
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         self.api.create_bucket('bucket2', 'allPrivate')
@@ -424,7 +460,25 @@ class TestApi:
             self.api.list_buckets()
         assert str(excinfo.value) == 'Application key is restricted to bucket: bucket1'
 
-    def test_list_buckets_with_restriction_and_wrong_id(self):
+    @pytest.mark.apiver(from_ver=3)
+    def test_list_buckets_with_restriction_and_no_name_v3(self):
+        self._authorize_account()
+        bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
+        self.api.create_bucket('bucket3', 'allPrivate')
+        key = create_key_multibucket(
+            self.api, ['listBuckets'], 'key1', bucket_ids=[bucket1.id_, bucket2.id_]
+        )
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
+        with pytest.raises(RestrictedBucket):
+            self.api.list_buckets()
+
+    @pytest.mark.apiver(to_ver=2)
+    def test_list_buckets_with_restriction_and_wrong_id_v2(self):
         self._authorize_account()
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         self.api.create_bucket('bucket2', 'allPrivate')
@@ -438,6 +492,23 @@ class TestApi:
             self.api.list_buckets(bucket_id='not the one bound to the key')
         assert str(excinfo.value) == f'Application key is restricted to bucket: {bucket1.id_}'
 
+    @pytest.mark.apiver(from_ver=3)
+    def test_list_buckets_with_restriction_and_wrong_id_v3(self):
+        self._authorize_account()
+        bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
+        self.api.create_bucket('bucket3', 'allPrivate')
+        key = create_key_multibucket(
+            self.api, ['listBuckets'], 'key1', bucket_ids=[bucket1.id_, bucket2.id_]
+        )
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
+        with pytest.raises(RestrictedBucket):
+            self.api.list_buckets(bucket_id='not the one bound to the key')
+
     def _authorize_account(self):
         self.api.authorize_account(
             application_key_id=self.application_key_id,
@@ -542,7 +613,7 @@ class TestApi:
         delete_result = self.api.delete_key_by_id(create_result['applicationKeyId'])
         self.assertDeleteAndCreateResult(create_result, delete_result.as_dict())
 
-    @pytest.mark.apiver(from_ver=2)
+    @pytest.mark.apiver(2)
     def test_create_and_delete_key_v2(self):
         self._authorize_account()
         bucket = self.api.create_bucket('bucket', 'allPrivate')
@@ -580,6 +651,35 @@ class TestApi:
         delete_result = self.api.delete_key_by_id(create_result.id_)
         self.assertDeleteAndCreateResult(create_result, delete_result)
 
+    @pytest.mark.apiver(from_ver=3)
+    def test_create_and_delete_key_v3(self):
+        self._authorize_account()
+        bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
+        now = time.time()
+        create_result = self.api.create_key(
+            ['readFiles'],
+            'testkey',
+            valid_duration_seconds=100,
+            bucket_ids=[bucket1.id_, bucket2.id_],
+            name_prefix='name',
+        )
+        assert isinstance(create_result, FullApplicationKey)
+        assert create_result.key_name == 'testkey'
+        assert create_result.capabilities == ['readFiles']
+        assert create_result.account_id == self.account_info.get_account_id()
+        assert (
+            (now + 100 - 10) * 1000
+            < create_result.expiration_timestamp_millis
+            < (now + 100 + 10) * 1000
+        )
+        assert create_result.bucket_ids == [bucket1.id_, bucket2.id_]
+        assert create_result.name_prefix == 'name'
+        # assert create_result.options == ...  TODO
+
+        delete_result = self.api.delete_key(create_result)
+        self.assertDeleteAndCreateResult(create_result, delete_result)
+
     def assertDeleteAndCreateResult(self, create_result, delete_result):
         if apiver_deps.V <= 1:
             create_result.pop('applicationKey')
@@ -593,7 +693,10 @@ class TestApi:
                 delete_result.expiration_timestamp_millis
                 == create_result.expiration_timestamp_millis
             )
-            assert delete_result.bucket_id == create_result.bucket_id
+            if apiver_deps.V < 3:
+                assert delete_result.bucket_id == create_result.bucket_id
+            else:
+                assert delete_result.bucket_ids == create_result.bucket_ids
             assert delete_result.name_prefix == create_result.name_prefix
 
     @pytest.mark.apiver(to_ver=1)
