@@ -64,6 +64,7 @@ class TestExceptions:
     @pytest.mark.apiver(to_ver=1)
     def test_command_error(self):
         from apiver_deps_exception import CommandError
+
         try:
             raise CommandError('foo')
         except CommandError as e:
@@ -73,8 +74,9 @@ class TestExceptions:
 class TestInterpretError:
     def test_file_already_hidden(self):
         self._check_one(FileAlreadyHidden, 400, 'already_hidden', '', {})
-        assert 'File already hidden: file.txt' == \
-            str(interpret_b2_error(400, 'already_hidden', '', {}, {'fileName': 'file.txt'}))
+        assert 'File already hidden: file.txt' == str(
+            interpret_b2_error(400, 'already_hidden', '', {}, {'fileName': 'file.txt'})
+        )
 
     def test_bad_json(self):
         self._check_one(BadJson, 400, 'bad_json', '', {})
@@ -83,34 +85,34 @@ class TestInterpretError:
         self._check_one(FileNotPresent, 400, 'no_such_file', '', {})
         self._check_one(FileNotPresent, 400, 'file_not_present', '', {})
         self._check_one(FileNotPresent, 404, 'not_found', '', {})
-        assert 'File not present: file.txt' == \
-            str(interpret_b2_error(404, 'not_found', '', {}, {'fileName': 'file.txt'}))
-        assert 'File not present: 01010101' == \
-            str(interpret_b2_error(404, 'not_found', '', {}, {'fileId': '01010101'}))
+        assert 'File not present: file.txt' == str(
+            interpret_b2_error(404, 'not_found', '', {}, {'fileName': 'file.txt'})
+        )
+        assert 'File not present: 01010101' == str(
+            interpret_b2_error(404, 'not_found', '', {}, {'fileId': '01010101'})
+        )
 
     def test_file_or_bucket_not_present(self):
         self._check_one(ResourceNotFound, 404, None, None, {})
-        assert 'No such file, bucket, or endpoint: ' == \
-            str(interpret_b2_error(404, None, None, {}))
+        assert 'No such file, bucket, or endpoint: ' == str(interpret_b2_error(404, None, None, {}))
 
     def test_duplicate_bucket_name(self):
         self._check_one(DuplicateBucketName, 400, 'duplicate_bucket_name', '', {})
-        assert 'Bucket name is already in use: my-bucket' == \
-            str(
-                interpret_b2_error(
-                    400, 'duplicate_bucket_name', '', {}, {'bucketName': 'my-bucket'}
-                )
-            )
+        assert 'Bucket name is already in use: my-bucket' == str(
+            interpret_b2_error(400, 'duplicate_bucket_name', '', {}, {'bucketName': 'my-bucket'})
+        )
 
     def test_missing_part(self):
         self._check_one(MissingPart, 400, 'missing_part', '', {})
-        assert 'Part number has not been uploaded: my-file-id' == \
-            str(interpret_b2_error(400, 'missing_part', '', {}, {'fileId': 'my-file-id'}))
+        assert 'Part number has not been uploaded: my-file-id' == str(
+            interpret_b2_error(400, 'missing_part', '', {}, {'fileId': 'my-file-id'})
+        )
 
     def test_part_sha1_mismatch(self):
         self._check_one(PartSha1Mismatch, 400, 'part_sha1_mismatch', '', {})
-        assert 'Part number my-file-id has wrong SHA1' == \
-            str(interpret_b2_error(400, 'part_sha1_mismatch', '', {}, {'fileId': 'my-file-id'}))
+        assert 'Part number my-file-id has wrong SHA1' == str(
+            interpret_b2_error(400, 'part_sha1_mismatch', '', {}, {'fileId': 'my-file-id'})
+        )
 
     def test_unauthorized(self):
         self._check_one(Unauthorized, 401, '', '', {})
@@ -179,12 +181,13 @@ class TestInterpretError:
         return actual_exception
 
     @pytest.mark.parametrize(
-        "status, code, expected_exception_cls", [
-            (401, "email_not_verified", EmailNotVerified),
-            (401, "no_payment_history", NoPaymentHistory),
-        ]
+        'status, code, expected_exception_cls',
+        [
+            (401, 'email_not_verified', EmailNotVerified),
+            (401, 'no_payment_history', NoPaymentHistory),
+        ],
     )
     def test_simple_error_handlers(self, status, code, expected_exception_cls):
-        error = interpret_b2_error(status, code, "", {})
+        error = interpret_b2_error(status, code, '', {})
         assert isinstance(error, expected_exception_cls)
         assert error.code == code
