@@ -9,6 +9,6 @@
 ######################################################################
 from __future__ import annotations
 
-from b2sdk._v3 import *  # noqa
+from b2sdk.v3 import *  # noqa
 
 V = 3
